@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.15_53'; 
+$VERSION = '1.15_54'; 
 $VERSION = eval $VERSION;
 
 use Config;
@@ -1135,11 +1135,21 @@ sub _temp_filename {
 sub _timeout_wrapper {
     my ($cmd, $timeout) = @_;
     
+    eval "use Proc::Killfam ()";
+    if ($@) {
+        $CPAN::Frontend->mywarn( << 'HERE' );
+CPAN::Reporter: you need Proc::Killfam for inactivity_timeout support.
+Continuing without timeout...
+HERE
+        return;
+    }
+
     # protect shell quotes
     $cmd = quotemeta($cmd);
 
     my $wrapper = sprintf << 'HERE', $timeout, $cmd, $cmd;
 use strict;
+use Proc::Killfam 'killfam';
 my ($pid, $exitcode);
 eval {
     local $SIG{CHLD};
@@ -1151,13 +1161,12 @@ eval {
         my $wstat = waitpid $pid, 0;
         $exitcode = $wstat == -1 ? -1 : $?;
     } else {    #child
-        setpgrp; # new process group for targeted kill
         exec "%s";
     }
 };
 alarm 0;
 if ($pid && $@ =~ /Timeout/){
-    kill -9, $pid;
+    killfam 9, $pid;
     my $wstat = waitpid $pid, 0;
     $exitcode = $wstat == -1 ? -1 : $?;
 }
