@@ -1,7 +1,7 @@
 package CPAN::Reporter::Config;
 use strict; 
 use vars qw/$VERSION/;
-$VERSION = '1.15_53'; 
+$VERSION = '1.15_54'; 
 $VERSION = eval $VERSION;
 
 use Config::Tiny ();
@@ -672,7 +672,8 @@ will be halted after this many seconds; useful for unattended smoke testing
 to stop after some amount of time; generally, this should be large -- 
 900 seconds or more -- as some distributions' tests take quite a long time to 
 run.  On MSWin32, [Win32::Job] is a needed and trying to kill a processes may 
-actually deadlock in some situations -- so use at your own risk
+actually deadlock in some situations -- so use at your own risk.  On other
+platforms, [Proc::Killfam] is required.
 * {editor = <editor>} -- editor to use to edit the test report; if not set,
 Test::Reporter will use environment variables {VISUAL}, {EDITOR} or {EDIT}
 (in that order) to find an editor 
